Uses of Class org.openqa.selenium.server.htmlrunner.HTMLTestResults (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV NEXT | FRAMES NO FRAMES

## Uses of Class
org.openqa.selenium.server.htmlrunner.HTMLTestResults

Packages that use HTMLTestResults
org.openqa.selenium.server.htmlrunner | Provides classes to launch Selenium Core HTML test suites and handle their test results.

Uses of HTMLTestResults in org.openqa.selenium.server.htmlrunner

Methods in org.openqa.selenium.server.htmlrunner that return HTMLTestResults
`HTMLTestResults` | `HTMLLauncher.getResults()`

Methods in org.openqa.selenium.server.htmlrunner with parameters of type HTMLTestResults
`void` | `HTMLResultsListener.processResults(HTMLTestResults results)`
`void` | `HTMLLauncher.processResults(HTMLTestResults resultsParm)` Accepts HTMLTestResults for later asynchronous handling
`void` | `HTMLLauncher.setResults(HTMLTestResults results)`

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV NEXT | FRAMES NO FRAMES

Copyright © 2009. All Rights Reserved.